# json-convenience
Additional methods for handling json files in python.

## Requirements
None

## Install
install using pip : ```python -m pip install json-convenience```

## Usage
- import: ```import json_convenience``` or ```from json_convenience import ...```  
- overview: start python console and run  ```help(json_convenience)```